Videos
======

`Life in Syntropy <https://vimeo.com/146953911>`__
--------------------------------------------------

Les bénéfices d'élaguer:
  1. Augmente l'activité des racines, modifiant sa mychorize. Une des conséquences de ce nouveau métabolisme est la production d'acide gibbérellique qui incite les plantes à pousser.
  2. Ces nouvelles pousses renforcent leurs relations symbiotiques avec les bactéries et les champignons, ce qui entraîne la disponibilité de nutriments. Ce processus est comme la fertilisation du champ.
  3. Le taux de photosynthèse des plantes élaguées est plus élevé que les plantes non-élaguées. Plus de photosynthèse signifie plus de carbone séquestré et signifie aussi que plus de lumière solaire est utilisée, rafraîchissant ainsi l'environnement. Un environnement plus frais signifie plus d'eau.
